4.57. umbra.ui.widgets.search_QLineEdit — Umbra 1.0.9 documentation

# 4.57. umbra.ui.widgets.search_QLineEdit

search_QLineEdit.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `Search_QLineEdit` class.

Others:

## 4.57.1. Module Attributes

`umbra.ui.widgets.search_QLineEdit.` `LOGGER`

## 4.57.2. Classes

class `umbra.ui.widgets.search_QLineEdit.` `Search_QLineEdit`(parent=None, uiSearchImage=None, uiSearchClickedImage=None, uiClearImage=None, uiClearClickedImage=None)

  Bases: `PyQt4.QtGui.QLineEdit`

  Defines a QLineEdit subclass providing a search field with clearing capabilities.

  Initializes the class.

  Parameters: | parent (QObject) – Widget parent. uiSearchImage (unicode) – Search button image path. uiSearchClickedImage (unicode) – Search button clicked image path. uiClearImage (unicode) – Clear button image path. uiClearClickedImage (unicode) – Clear button clicked image path.

  `uiSearchImage`

    Property for self.__uiSearchImage attribute.

    Returns: | self.__uiSearchImage.
    Return type: | unicode

  `uiSearchClickedImage`

    Property for self.__uiSearchClickedImage attribute.

    Returns: | self.__uiSearchClickedImage.
    Return type: | unicode

  `uiClearImage`

    Property for self.__uiClearImage attribute.

    Returns: | self.__uiClearImage.
    Return type: | unicode

  `uiClearClickedImage`

    Property for self.__uiClearClickedImage attribute.

    Returns: | self.__uiClearClickedImage.
    Return type: | unicode

  `searchActiveLabel`

    Property for self.__searchActiveLabel attribute.

    Returns: | self.__searchActiveLabel.
    Return type: | QPushButton

  `clearButton`

    Property for self.__clearButton attribute.

    Returns: | self.__clearButton.
    Return type: | QPushButton

  `completer`

    Property for self.__completer attribute.

    Returns: | self.__completer.
    Return type: | QCompleter

  `completerVisibleItemsCount`

    Property for self.__completerVisibleItemsCount attribute.

    Returns: | self.__completerVisibleItemsCount.
    Return type: | int

  `resizeEvent`(event)

    Reimplements the `QLineEdit.QResizeEvent()` method.

    Parameters: | event (QResizeEvent) – Resize event.